@@ -1,5 +1,8 @@
+from wpimath.geometry import Transform3d, Pose3d, Rotation3d
+
+from robotpy_toolkit_7407.sensors.photonvision.photon_target import PhotonTarget
 from robotpy_toolkit_7407.sensors.photonvision.photon_camera import PhotonCamera
-from photonvision import PhotonUtils
+from photonvision import PhotonUtils, PhotonTrackedTarget
 from robotpy_apriltag import AprilTagFieldLayout
 from robotpy_toolkit_7407.sensors.gyro import Gyro
 
